California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 98 - EMINENT DOMAIN. LIMITS ON GOVERNMENT AUTHORITY. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287066 | CALIFORNIANS FOR NEIGHBORHOOD PROTECTION: YES ON PROP 99, NO ON PROP 98, A COALITION OF CONSERVATIONISTS, LABOR AND BUSINESS. A SPONSORED COMMITTEE OF THE CA LEAGUE OF CONSERVATION VOTERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1296303 | A COALITION OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION, FUNDED BY THOMAS COATES, THE CALIFORNIA ASSOCIATION OF REALTORS ISSUES PAC, AND THE CALIFORNIA FARM BUREAU FEDERATION, YES PROP 98 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306288 | EASTBAY COALITION NO ON 98/YES ON 99 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1285334 | NO 98/YES 99 - A COMMITTEE OF CITY AND COUNTY ASSOCIATIONS, TAXPAYERS AND ENVIRONMENTAL GROUPS, LEAGUE OF CALIFORNIA CITIES, CALIFORNIANS FOR NEIGHBORHOOD PROTECTION, COALITION OF CONSERVATIONISTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306797 | EVICTION DEFENSE COLLABORATIVE, INC. NO ON 98 YES ON 99 SPONSORED BY THE SAN FRANCISCO FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306845 | OAKLAND RISING NO ON 98 YES ON 99 COMMITTEE SPONSORED BY URBAN HABITAT | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306680 | NO ON 98/YES ON 99 COMMITTEE SPONSORED BY JUST CAUSE OAKLAND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307342 | TENANTS TOGETHER COMMITTEE AGAINST PROPOSITION 98, SPONSORED BY THE SAN FRANCISCO FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307176 | ASSOCIATION OF COMMUNITY ORGANIZATIONS FOR REFORM NOW (ACORN) VOTES ISSUES COMMITTEE - NO ON 98 AND YES ON 99 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304768 | COMMITTEE TO SAVE RENT CONTROL - NO ON 98/YES ON 99 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304750 | PROTECT SMALL BUSINESS PROPERTY RIGHTS - A PROJECT OF THE NATIONAL FEDERATION OF INDEPENDENT BUSINESS | SUPPORT